@@ -43,6 +43,15 @@
 #include "settings-keys.h"
 #include "legacy/gsm_color_button.h"
 
+static const char* LOAD_GRAPH_CSS = "\
+.loadgraph {\
+    background: linear-gradient(to bottom,\
+                      @theme_bg_color,\
+                      @theme_base_color\
+                      );\
+    color: mix (@theme_fg_color, @theme_bg_color, 0.5);\
+}\
+";
 
 static gboolean
 cb_window_key_press_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
@@ -174,6 +183,8 @@ create_sys_view (GsmApplication *app, GtkBuilder * builder)
     GtkLabel *label,*cpu_label;
     GtkGrid *table;
     GsmColorButton *color_picker;
+    GtkCssProvider *provider;
+
     LoadGraph *cpu_graph, *mem_graph, *net_graph;
 
     gint i;
@@ -181,6 +192,9 @@ create_sys_view (GsmApplication *app, GtkBuilder * builder)
     gchar *label_text;
     gchar *title_template;
 
+    provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (provider, LOAD_GRAPH_CSS, -1, NULL);
+    gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
     // Translators: color picker title, %s is CPU, Memory, Swap, Receiving, Sending
     title_template = g_strdup(_("Pick a Color for “%s”"));
 
@@ -312,6 +326,9 @@ create_sys_view (GsmApplication *app, GtkBuilder * builder)
     color_picker = gsm_color_button_new (
         &net_graph->colors.at(1), GSMCP_TYPE_NETWORK_OUT);
     gtk_widget_set_valign (GTK_WIDGET(color_picker), GTK_ALIGN_CENTER);
+    gtk_widget_set_hexpand (GTK_WIDGET(color_picker), true);
+    gtk_widget_set_halign (GTK_WIDGET(color_picker), GTK_ALIGN_END);
+
     g_signal_connect (G_OBJECT (color_picker), "color-set",
                       G_CALLBACK (cb_net_out_color_changed), app);
     title_text = g_strdup_printf(title_template, _("Sending"));
@@ -323,6 +340,12 @@ create_sys_view (GsmApplication *app, GtkBuilder * builder)
     gtk_grid_attach_next_to (table, GTK_WIDGET (load_graph_get_labels(net_graph)->net_out), GTK_WIDGET (label), GTK_POS_RIGHT, 1, 1);
     label = GTK_LABEL (gtk_builder_get_object(builder, "total_sent_label"));
     gtk_grid_attach_next_to (table, GTK_WIDGET (load_graph_get_labels(net_graph)->net_out_total), GTK_WIDGET (label), GTK_POS_RIGHT, 1, 1);
+    gtk_widget_set_hexpand (GTK_WIDGET(load_graph_get_labels(net_graph)->net_out_total), true);
+    gtk_widget_set_halign (GTK_WIDGET(load_graph_get_labels(net_graph)->net_out_total), GTK_ALIGN_START);
+
+    gtk_widget_set_hexpand (GTK_WIDGET(load_graph_get_labels(net_graph)->net_out), true);
+    gtk_widget_set_halign (GTK_WIDGET(load_graph_get_labels(net_graph)->net_out), GTK_ALIGN_START);
+
 
     app->net_graph = net_graph;
     g_free (title_template);
@@ -755,6 +778,21 @@ create_main_window (GsmApplication *app)
     g_object_unref (G_OBJECT (builder));
 }
 
+gboolean
+scroll_to_selection (gpointer data)
+{
+    GsmApplication *app = (GsmApplication *) data;
+    GList* paths = gtk_tree_selection_get_selected_rows (app->selection, NULL);
+    guint length = g_list_length(paths);
+    if (length > 0) {
+        GtkTreePath* last_path = (GtkTreePath*) g_list_nth_data(paths, length - 1);
+        gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (app->tree), last_path, NULL, FALSE, 0.0, 0.0);
+    }
+
+    g_list_free_full (paths, (GDestroyNotify) gtk_tree_path_free);
+    return FALSE;
+}
+
 void
 update_sensitivity(GsmApplication *app)
 {
@@ -795,4 +833,9 @@ update_sensitivity(GsmApplication *app)
 
     gtk_revealer_set_reveal_child (GTK_REVEALER (app->proc_actionbar_revealer),
                                    selected_sensitivity);
+
+    // Scrolls the table to selected row. Useful when the last row is obstructed by the revealer
+    guint duration_ms = gtk_revealer_get_transition_duration (GTK_REVEALER (app->proc_actionbar_revealer));
+    g_timeout_add (duration_ms, scroll_to_selection, app);
 }
+
